#
# spec file for package asdf
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           asdf
Version:        0.18.0
Release:        1.1
Summary:        Extendable version manager
License:        MIT
URL:            https://github.com/asdf-vm/asdf
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.23

%description
Extendable version manager with support for
Ruby, Node.js, Elixir, Erlang & more.

Manage multiple runtime versions with a single CLI tool,
extendable via plugins.

%prep
%autosetup -a 1

%build
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
go build -ldflags='-s -X main.version=%{version}' -o=./asdf ./cmd/asdf

%install
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Sat Jun  7 2025 Alessio Biancalana <dottorblaster@opensuse.org>
- Update to version 0.18.0:
  * chore: release 0.18.0 (#2128)
  * chore: revert chore release 0.18.0 (#2106) (#2127)
  * chore: release 0.18.0 (#2106)
  * fix: rename tool version filename environment variable for clarity (#2101)
  * docs: create dependencies page (#2124)
  * docs: correct dangerous cleanup command in upgrade guide (#2123)
  * fix: only return version starting with number when no filter is supplied (#2120)
  * docs: correct link to ASDF_CONFIG_FILE environment variable (#2119)
  * docs: upgrade upgrade guide to reference all available install methods (#2117)
  * feat: `asdf list` exit with status code of 0 when no versions installed (#2116)
  * fix: correct flag handling in commands run by `asdf exec` (#2115)
  * docs: document cleanup of ASDF_DATA_DIR in upgrade guide (#2114)
  * chore(deps): bump @types/node from 22.15.3 to 22.15.29 in /docs in the docs group (#2111)
  * docs: document unexpected shims on faq page (#2110)
  * fix: print all error output to stderr when shim can't be resolved (#2109)
  * fix: upgrade urfave/cli to version 3 (#2105)
  * docs: add missing information 0.16.0 upgrade instructions (#2103)
* Tue May 20 2025 Alessio Biancalana <dottorblaster@opensuse.org>
- Update to version 0.17.0:
  * chore: release 0.17.0 (#2084)
  * fix: ensures output always ends with a newline when printed (#2098)
  * fix: correct output of install command when system or path version set (#2097)
  * fix: handle tilde in env vars (#2092)
  * docs: add faq on version ranges in .tool-versions files (#2091)
  * docs: add faq item on use of latest in .tool-versions files (#2090)
  * fix: remove unused ForcePrepend option from Go code (#2089)
  * feat: switch back to native git client (#1998)
  * feat(golang-rewrite): add support for shim templates resolution (#2076)
  * test(golang-rewrite): ignore global git config on repotest (#2068)
  * chore: adjusting release-please-action config (#2083)
  * chore: adjusting release-please-action config (#2082)
  * chore: add proper release please config file (#2080)
  * chore: fix release please config version is updated in all files (#2079)
  * fix: set correct version for go install and make builds (#2077)
  * chore(docs): bump vite from 5.4.18 to 5.4.19 in /docs (#2075)
  * chore(docs): bump @types/node from 22.13.16 to 22.15.3 in /docs in the docs group (#2074)
  * feat: log failure to add plugin in "plugin test" (#2059)
  * docs: Fix link to bin/list-bin-paths (#2066)
  * chore(docs): bump vite from 5.4.17 to 5.4.18 in /docs (#2065)
  * chore(deps): bump golang.org/x/net from 0.36.0 to 0.38.0 (#2064)
  * fix: remove default error action from plugin command (#2027)
  * fix: correct intersection logic in `shims.FindExecutable` function so ordering of multiple versions is preserved (#2063)
  * docs: use release-please-manifest.json for version on documentation website (#2050)
  * fix: address linter warning
  * chore(docs): bump vite from 5.4.14 to 5.4.17 in /docs (#2056)
  * chore(docs): add binary download link to guide page (#2052)
  * chore(docs): bump the docs group in /docs with 2 updates (#2048)
  * add test for VersionStringFromFSFormat
  * for FS format not from
  * move version parsing of FS format to direct fs file name read
  * chore(docs): bump vite from 5.4.14 to 5.4.17 in /docs (#2056)
  * chore(docs): add binary download link to guide page (#2052)
  * chore(docs): bump the docs group in /docs with 2 updates (#2048)
  * update naming to reflect that this is tool not plugin version
  * move to shims.parse to for better project wide handling
  * support ref installed tool shims
* Thu Mar 27 2025 Alessio Biancalana <dottorblaster@opensuse.org>
- Update to version 0.16.7:
  * chore: release 0.16.7 (#2039)
  * fix: remove comment from first line zsh completion output (#2035) (#2037)
* Sat Mar 22 2025 Alessio Biancalana <dottorblaster@opensuse.org>
- Update to version 0.16.6:
  * chore: release 0.16.6 (#2007)
  * docs: add Zypper to the package managers in which asdf is available (#2031)
  * fix: remove filtering from latest-stable call (#2032)
  * chore: ignore case for value of `ASDF_FORCE_PREPEND` environment variable (#2026)
  * fix: remove install directory for version when install fails (#2024)
  * fix: improve zsh completion suggestions (#2022)
  * fix: correct concurrency to align with documentation (#2014)
  * fix: correct handling of `ASDF_FORCE_PREPEND` environment variable (#2011)
  * chore(deps): bump golang.org/x/net from 0.33.0 to 0.36.0 (#2017)
  * fix: correct ASDF_INSTALL_* envvar unset test (#2006)
* Tue Mar  4 2025 Alessio Biancalana <dottorblaster@opensuse.org>
- Update to version 0.16.5:
  * chore: release 0.16.5 (#1985)
  * fix: preserve files untracked by Git on plugin update (#1995)
  * fix: build static binary to improve portability (#1993)
  * fix: latest version returns latest version (#1996)
  * chore(docs): bump the docs group in /docs with 2 updates (#2000)
  * fix: set correct env vars on recursive calls (#1989)
  * fix: correct exit status when sub-command does not exist (#1991)
  * fix: simplify env vars parsing (#1988)
  * fix: always propagate env variables when executing commands (#1982)
* Mon Mar  3 2025 Alessio Biancalana <dottorblaster@opensuse.org>
- Fix copyright
* Sat Mar  1 2025 Alessio Biancalana <dottorblaster@opensuse.org>
- First asdf package submission
